import React from 'react';
import { Email, Submit } from './index.jsx';
import { request } from 'graphql-request';

const mutation = `
    mutation newsletterSignup ($email: String!) {
        newsletterSignup (
            email: $email
        )
    }
`;

class Signup extends React.Component {
    constructor(props) {
        super(props);
        this.state = {
            isSignedUp: false,
            email: '',
            buttonState: 'primary',
            buttonLoading: false,
            buttonText: 'Subscribe',
            inputDisabled: false
        };

        this.handleSubmit = this.handleSubmit.bind(this);
        this.handleChange = this.handleChange.bind(this);
    }

    handleSubmit(e) {
        this.setState({buttonLoading: true, buttonText: 'Subscribing...', inputDisabled: true});

        request('graphql', mutation, {email: this.state.email}).then(data => {
            this.setState({buttonLoading: false});
            if(data.newsletterSignup) {
                this.setState({buttonState: 'success', buttonText: 'Subscribed!'});

                setTimeout(() => this.setState({
                    inputDisabled: false,
                    email: '',
                    buttonState: 'primary',
                    buttonText: 'Subscribe'
                }), 5000);
            } else {
                this.setState({buttonState: 'danger', buttonText: 'Already Subscribed!', inputDisabled: false});
            }
        });

        e.preventDefault();
    }

    handleChange(e) {
        this.setState({
            buttonState: 'primary',
            buttonText: 'Subscribe'
        });

        this.setState({email: e.target.value});
    }

    render() {
        return (
            <form className="form subscribe" onSubmit={this.handleSubmit}>
                <Email field_id="email" change={this.handleChange} disabled={this.state.inputDisabled} value={this.state.email}  />
                <Submit text={this.state.buttonText} clickHandler={this.handleSubmit} buttonState={this.state.buttonState}
                        buttonLoading={this.state.buttonLoading} />
            </form>
        );
    }
}

export default Signup;